# Copyright 2020 Max Planck Institute for Dynamics and Self-Organization
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import sys
from setuptools import setup

if sys.hexversion < 0x3000000:
    raise NotImplementedError('Python < 3.0 not supported.')

with open('README.rst', encoding="utf-8") as file:
    long_description = file.read()


setup(name='pypmadra',
      version='0.2',
      description='Poly-Multiplicity Airborne Disease Risk Assessment '
      '(PMADRA) in Python.',
      long_description=long_description,
      author='LFPB (Max Planck Institute for Dynamics and Self-Organization)',
      author_email='freja.nordsiek at ds.mpg.de',
      url='https://gitlab.gwdg.de/mpids-lfpn-public/pmadra/pypmadra',
      packages=['pypmadra',
                'pypmadra.const_coeff'],
      install_requires=['numpy>=1.17', 'scipy>0.18'],
      license='MIT',
      keywords='risk-assessment airborne disease transmission aerosol '
      'infection wells-riley',
      zip_safe=True,
      classifiers=[
          "Programming Language :: Python :: 3 :: Only",
          "Development Status :: 3 - Alpha",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
          "Intended Audience :: Science/Research",
          "Intended Audience :: Healthcare Industry",
          "Topic :: Scientific/Engineering :: Medical Science Apps."])
